USE TESTDB
GO

--password encrypted with SHA1.
CREATE PROCEDURE TESTDB.InsertUser
		@fname		varchar(50),
		@lname		varchar(50),
		@email		varchar(100),
		@phone		varchar(13),
		@username	varchar(50),
		@pwd varchar(50)
AS
BEGIN
	DECLARE @name		AS varchar(50),
			@pwdencrypt AS varchar(100),
			@currdate 	AS datetime

	--Check for NULLS on required fields
	IF @fname IS NOT NULL AND @lname IS NOT NULL AND @email IS NOT NULL AND @username IS NOT NULL AND @pwd IS NOT NULL
		BEGIN
			--Check for empty strings on required fields
			IF LTRIM(RTRIM(@fname)) != '' AND LTRIM(RTRIM(@lname)) != '' AND LTRIM(RTRIM(@email)) != '' AND LTRIM(RTRIM(@username)) != '' AND LTRIM(RTRIM(@pwd)) != ''
				BEGIN
					--Check if username already exists
					SELECT @name = (SELECT FIRST_NAME FROM TESTDB.TEST_USER WHERE USERNAME = @username)
					IF @name IS NULL
						BEGIN
							SET @currdate = GETDATE()
							SET @pwdencrypt = substring(master.dbo.fn_varbintohexstr(HashBytes('SHA1',@pwd)),3,len(master.dbo.fn_varbintohexstr(HashBytes('SHA1',@pwd))))

							INSERT INTO TESTDB.TEST_USER(USERNAME, FIRST_NAME, LAST_NAME, EMAIL, PHONE, PASSWORD, CREATED_BY, UPDATED_BY, CREATED_DATE, UPDATED_DATE) 
								VALUES(@username, @fname, @lname, @email, @phone, @pwdencrypt,'edsadmin', 'edsadmin', @currdate, NULL)

							--Success
							PRINT 'User insertion was successfull.'
						END
					ELSE
						BEGIN
							--User already exists
							PRINT 'The user was not inserted. Username already exists'
						END
				END
			ELSE
				BEGIN
					--Missing required fields
					PRINT 'The user was not inserted. Missing required field(s). First name, last name, email, username, and password are required.'
				END
		END
	ELSE
		BEGIN
			--Missing required fields
			PRINT 'The user was not inserted. Missing required field(s). First name, last name, email, username, and password are required.'
		END
END

set ANSI_NULLS ON
set QUOTED_IDENTIFIER ON
go



--Change user password
CREATE PROCEDURE [TESTDB].[ChangePassword]
		@username varchar(50),
		@pwd varchar(50)
AS
BEGIN
	DECLARE @fname	AS varchar(50)

	--
	IF @username IS NOT NULL AND @pwd IS NOT NULL
		BEGIN
			--
			IF LTRIM(RTRIM(@username)) != '' AND LTRIM(RTRIM(@pwd)) != ''
				BEGIN
					--
					SELECT @fname = (SELECT FIRST_NAME FROM TESTDB.TEST_USER WHERE USERNAME = @username)
					IF @fname IS NOT NULL
						BEGIN
							UPDATE TESTDB.TEST_USER
								SET PASSWORD = substring(master.dbo.fn_varbintohexstr(HashBytes('SHA1',@pwd)),3,len(master.dbo.fn_varbintohexstr(HashBytes('SHA1',@pwd)))),
									UPDATED_DATE = NULL
								WHERE USERNAME = @username
								--PASSWORD CHANGE SUCCESSFULL
								PRINT 'Password for ' + @username + ' successfully changed.'
						END
					ELSE
						BEGIN
							--USER DOES NOT EXIST
							PRINT 'Password change failed. User ' + @username + ' does not exist.'
						END
				END
			ELSE
				BEGIN
					--USERNAME OR PASSWORD NOT SUPPLIED
					PRINT 'Password change failed. Username or password not supplied.'
				END
		END
	ELSE
		BEGIN
			--USERNAME OR PASSWORD NOT SUPPLIED
			PRINT 'Password change failed. Username or password not supplied.'
		END
END

