package com.uccs.itapps.testproject.beans.session;

import com.uccs.itapps.testproject.beans.entity.Role;
import com.uccs.itapps.testproject.beans.entity.User;

import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import javax.ejb.Remove;
import javax.ejb.Stateful;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.jboss.seam.annotations.Destroy;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.faces.FacesMessages;
import org.jboss.seam.log.Log;
import org.jboss.seam.security.Identity;
import org.jboss.seam.ScopeType;


@Stateful
@Name ( "authenticator")
@Scope(ScopeType.SESSION)
public class AuthBean implements Auth
{
	@Logger Log log;

	@In
	Identity identity;

	@PersistenceContext
	EntityManager em;

	public boolean authenticate(){

		log.info("authenticating #0", identity.getUsername());

		try{
			User user = (User) em.createQuery("from User where username = :username and password = :password")
				.setParameter("username", identity.getUsername())
				.setParameter("password", getHashedPwd(identity.getPassword()))
				.getSingleResult();

			if(user.getRoles() != null){
				for(Role mr : user.getRoles()){
					System.out.println("adding role: " + mr.getRoleName());
					identity.addRole(mr.getRoleName());
				}
			}

			return true;
		}
		catch(Exception ex){
			//FacesMessages.instance().add("Invalid username/password");
			return false;
		}
	}

    private String convertToHex(byte[] data) {
        StringBuffer buf = new StringBuffer();
        for (int i = 0; i < data.length; i++) {
        	int halfbyte = (data[i] >>> 4) & 0x0F;
        	int two_halfs = 0;
        	do {
	            if ((0 <= halfbyte) && (halfbyte <= 9))
	                buf.append((char) ('0' + halfbyte));
	            else
	            	buf.append((char) ('a' + (halfbyte - 10)));
	            halfbyte = data[i] & 0x0F;
        	} while(two_halfs++ < 1);
        }
        return buf.toString();
    }

    private String getHashedPwd(String pwd) throws NoSuchAlgorithmException, UnsupportedEncodingException  {
    	MessageDigest md;
    	md = MessageDigest.getInstance("SHA-1");
    	byte[] sha1hash = new byte[40];
    	md.update(pwd.getBytes("iso-8859-1"), 0, pwd.length());
    	sha1hash = md.digest();
    	return convertToHex(sha1hash);
    }


	@Destroy @Remove
	public void remove(){}
}
